@@ -7,7 +7,7 @@ from contextlib import contextmanager
 import os
 import shutil
 import tempfile
-from typing import Dict, List, Iterator
+from typing import Any, Dict, List, Iterator
 
 # third-party
 import setuptools  # type: ignore
@@ -91,7 +91,7 @@ def get_data_files(pkg_name: str, data_dir: str = "data") -> List[str]:
 
 # pylint: disable=too-many-arguments
 def setup(
-    pkg_info: Dict[str, str],
+    pkg_info: Dict[str, Any],
     author_info: Dict[str, str],
     url_override: str = None,
     entry_override: str = None,
@@ -107,7 +107,7 @@ def setup(
         entry_override = pkg_info["name"]
 
     if console_overrides is None:
-        entry_str = "{}={}.entry:main".format(entry_override, pkg_info["name"])
+        entry_str = "{}={}.entry:main".format(entry_override, pkg_info["slug"])
         console_overrides = [entry_str]
 
     if url_override is None:
@@ -118,10 +118,13 @@ def setup(
 
     if classifiers_override is None:
         classifiers_override = [
-            "Programming Language :: Python :: 3",
             "License :: OSI Approved :: MIT License",
             "Operating System :: OS Independent",
         ]
+    for version in pkg_info.get("versions", []):
+        classifiers_override.append(
+            "Programming Language :: Python :: {}".format(version)
+        )
 
     req_files = [default_requirements_file()]
     requirements = []
@@ -131,7 +134,7 @@ def setup(
     with tempfile.TemporaryDirectory() as temp_dir:
         working_dir = temp_dir
         dir_contents = os.listdir(os.getcwd())
-        if pkg_info["name"] in dir_contents:
+        if pkg_info["slug"] in dir_contents:
             working_dir = os.getcwd()
 
         with inject_self(working_dir):
@@ -144,15 +147,21 @@ def setup(
                 long_description=get_long_description(),
                 long_description_content_type="text/markdown",
                 url=url_override,
-                packages=setuptools.find_packages(),
+                packages=setuptools.find_packages(
+                    exclude=["tests", "tests.*"]
+                ),
                 classifiers=classifiers_override,
-                python_requires=">=3.6",
+                python_requires=">={}".format(
+                    pkg_info.get("versions", ["3.6"])[0]
+                ),
                 entry_points={"console_scripts": console_overrides},
                 install_requires=requirements,
                 package_data={
-                    pkg_info["name"]: (
-                        get_data_files(pkg_info["name"]) + ["py.typed"]
+                    pkg_info["slug"]: (
+                        get_data_files(pkg_info["slug"])
+                        + ["py.typed", "*.pyi"]
                     ),
+                    "": ["*.pyi"],
                     REQ_DIR: [os.path.basename(req) for req in req_files],
                 },
             )
