@@ -5,10 +5,10 @@ vtelem - A generic element that can be read from and written to buffers.
 # built-in
 import logging
 from typing import Any, Callable
-import threading
 
 # internal
 from vtelem.enums.primitive import Primitive, default_val, get_size
+from . import DEFAULTS
 from .byte_buffer import ByteBuffer
 
 LOG = logging.getLogger(__name__)
@@ -29,7 +29,6 @@ class TypePrimitive:
         self.data: Any = default_val(self.type)
         self.changed_cb = changed_cb
         self.last_set: float = float()
-        self.lock = threading.RLock()
 
     def __eq__(self, other) -> bool:
         """Generic equality check for primitives."""
@@ -46,9 +45,7 @@ class TypePrimitive:
     def add(self, data: Any, time: float = None) -> bool:
         """Safely add some amount to the primitive."""
 
-        with self.lock:
-            result = self.set(self.get() + data, time)
-        return result
+        return self.set(self.get() + data, time)
 
     def set(self, data: Any, time: float = None) -> bool:
         """Set this primitive's data manually."""
@@ -56,26 +53,25 @@ class TypePrimitive:
         if time is None:
             time = float()
 
-        expected_type = self.type.value["type"]
+        expected_type = self.type.value.type
         if isinstance(data, expected_type):
 
             # validate the desired value
-            if not self.type.value["validate"](self.type, data):
+            if not self.type.value.validate(self.type.value, data):
                 LOG.warning(
                     "value '%s' not valid for type '%s'", data, self.type
                 )
                 return False
 
-            with self.lock:
-                # setup changed-callback if necessary
-                if self.changed_cb is not None:
-                    cb_args = [(self.data, self.last_set), (data, time)]
-                    prev_data = self.data
+            # setup changed-callback if necessary
+            if self.changed_cb is not None:
+                cb_args = [(self.data, self.last_set), (data, time)]
+                prev_data = self.data
 
-                # set the new value
-                self.data = expected_type(data)
-                if time is not None:
-                    self.last_set = time
+            # set the new value
+            self.data = expected_type(data)
+            if time is not None:
+                self.last_set = time
 
             # call changed-callback
             if self.changed_cb is not None and prev_data != data:
@@ -117,3 +113,10 @@ class TypePrimitive:
             result = buf.read(self.type)
         self.data = result
         return result
+
+
+def new_default(default: str, changed_cb: Callable = None) -> TypePrimitive:
+    """Construct a new type primitive from a default type alias."""
+
+    assert default in DEFAULTS
+    return TypePrimitive(DEFAULTS[default], changed_cb)
