@@ -7,9 +7,9 @@ vtelem - A module for creating functions based on telemetry environment
 from typing import Tuple
 
 # internal
-from vtelem.classes.channel import Channel
-from vtelem.classes.telemetry_environment import TelemetryEnvironment
-from vtelem.classes.command_queue_daemon import CommandQueueDaemon
+from vtelem.channel import Channel
+from vtelem.daemon.command_queue import CommandQueueDaemon
+from vtelem.telemetry.environment import TelemetryEnvironment
 from vtelem.types.command_queue_daemon import ResultCbType
 
 
