@@ -7,7 +7,7 @@ import json
 from typing import Tuple
 
 # internal
-from vtelem.classes.command_queue_daemon import CommandQueueDaemon
+from vtelem.daemon.command_queue import CommandQueueDaemon
 from vtelem.classes.udp_client_manager import UdpClientManager
 from vtelem.types.command_queue_daemon import ResultCbType
 
