@@ -1,4 +1,3 @@
-
 """
 vtelem - Common type definitions for the command-queue daemon.
 """
@@ -8,5 +7,6 @@ from typing import Callable, Tuple, Dict, List, Optional
 
 ConsumerType = Callable[[dict], Tuple[bool, str]]
 ResultCbType = Callable[[bool, str], None]
-HandlersType = Dict[str, List[Tuple[ConsumerType, Optional[ResultCbType],
-                                    str]]]
+HandlersType = Dict[
+    str, List[Tuple[ConsumerType, Optional[ResultCbType], str]]
+]
